@@ -7,7 +7,8 @@ import sys
 import tempfile
 from typing import TYPE_CHECKING, Any, Dict, List, Optional
 
-from ansiblelint.prerun import prepare_environment
+from ansiblelint.app import get_app
+from ansiblelint.rules import RulesCollection
 
 if TYPE_CHECKING:
     # https://github.com/PyCQA/pylint/issues/3240
@@ -18,16 +19,15 @@ else:
 
 # Emulate command line execution initialization as without it Ansible module
 # would be loaded with incomplete module/role/collection list.
-prepare_environment()
+app = get_app(offline=True)
 
 # pylint: disable=wrong-import-position
 from ansiblelint.errors import MatchError  # noqa: E402
-from ansiblelint.rules import RulesCollection  # noqa: E402
 from ansiblelint.runner import Runner  # noqa: E402
 
 
 class RunFromText:
-    """Use Runner on temp files created from unittest text snippets."""
+    """Use Runner on temp files created from testing text snippets."""
 
     def __init__(self, collection: RulesCollection) -> None:
         """Initialize a RunFromText instance with rules collection."""
@@ -41,10 +41,10 @@ class RunFromText:
         """Lints received text as a playbook."""
         with tempfile.NamedTemporaryFile(
             mode="w", suffix=".yml", prefix="playbook"
-        ) as fp:
-            fp.write(playbook_text)
-            fp.flush()
-            results = self._call_runner(fp.name)
+        ) as fh:
+            fh.write(playbook_text)
+            fh.flush()
+            results = self._call_runner(fh.name)
         return results
 
     def run_role_tasks_main(self, tasks_main_text: str) -> List[MatchError]:
@@ -52,8 +52,8 @@ class RunFromText:
         role_path = tempfile.mkdtemp(prefix="role_")
         tasks_path = os.path.join(role_path, "tasks")
         os.makedirs(tasks_path)
-        with open(os.path.join(tasks_path, "main.yml"), "w") as fp:
-            fp.write(tasks_main_text)
+        with open(os.path.join(tasks_path, "main.yml"), "w", encoding="utf-8") as fh:
+            fh.write(tasks_main_text)
         results = self._call_runner(role_path)
         shutil.rmtree(role_path)
         return results
@@ -63,8 +63,19 @@ class RunFromText:
         role_path = tempfile.mkdtemp(prefix="role_")
         meta_path = os.path.join(role_path, "meta")
         os.makedirs(meta_path)
-        with open(os.path.join(meta_path, "main.yml"), "w") as fp:
-            fp.write(meta_main_text)
+        with open(os.path.join(meta_path, "main.yml"), "w", encoding="utf-8") as fh:
+            fh.write(meta_main_text)
+        results = self._call_runner(role_path)
+        shutil.rmtree(role_path)
+        return results
+
+    def run_role_defaults_main(self, defaults_main_text: str) -> List[MatchError]:
+        """Lints received text as vars file in defaults."""
+        role_path = tempfile.mkdtemp(prefix="role_")
+        defaults_path = os.path.join(role_path, "defaults")
+        os.makedirs(defaults_path)
+        with open(os.path.join(defaults_path, "main.yml"), "w", encoding="utf-8") as fh:
+            fh.write(defaults_main_text)
         results = self._call_runner(role_path)
         shutil.rmtree(role_path)
         return results
